@@ -416,7 +416,7 @@ class MyWhatify:
         return ret_list
 
     @classmethod
-    def get_prediction(cls, predict_id, len=10):
+    def get_prediction(cls, predict_id, len=None):
         with allure.step('getting prediction list for predict_id: ' + str(predict_id) + ' len: ' + str(len)):
             ret_prediction = None
             predict_results = my_toolkit.Prediction.get(predict_id)
@@ -425,7 +425,8 @@ class MyWhatify:
 
             if download_url is not None:
                 df_predict = pd.read_csv(download_url)
-                ret_prediction = df_predict.head(len)
+                ret_prediction = df_predict.head(len) if len else df_predict
+
         return ret_prediction
 
     @classmethod
